package com.example.scan;

import android.app.Activity;
import android.os.Bundle;
import android.os.IScanListener;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.ropeok.AppTest;
import com.example.iscandemo.iScanInterface;

import io.flutter.Log;
import io.flutter.embedding.android.FlutterActivity;
import io.flutter.embedding.engine.FlutterEngine;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.embedding.engine.plugins.util.GeneratedPluginRegister;
import io.flutter.plugin.common.EventChannel;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;

/** ScanPlugin */
public class ScanPlugin extends FlutterActivity implements FlutterPlugin, ActivityAware {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private MethodChannel methodChannel;
  private EventChannel eventChannel;
  private EventChannel.EventSink _eventSink = null;
  private final static  String TAG = "iScanDemo";
  //定义接口操作对象
  public iScanInterface miScanInterface;
  public String resultStr;

  //定义数据回调接口
  private IScanListener scanResltListener = new IScanListener(){
    /**
     * @param data 条码数据
     * @param type 条码类型
     * @param decodeTime 解码耗时
     * @param keyDownTime 按键时间
     * @param imagePath 图片路径，注意：默认图片输出为关闭状态；
     *                                  如果需要条码图片需要打开图片输出选项。
     */
    @Override
    public void onScanResults(String data, final  int type, long decodeTime, long keyDownTime, String imagePath) {
            Log.d(TAG, "onScanResults: data="+data);
            Log.d(TAG, "onScanResults: type="+type);
            Log.d(TAG, "onScanResults: decodeTime="+decodeTime);
            Log.d(TAG, "onScanResults: keyDownTime="+keyDownTime);
            Log.d(TAG, "onScanResults: imagePath="+imagePath);



      final String result="data:"+data+"\r\n"
              +"type:"+type+"\n"
              +"decodeTime:"+decodeTime+"\n"
              +"keyDownTime:"+keyDownTime+"\n"
              +"imagePath:"+imagePath+"\n";

      runOnUiThread(new Runnable() {
        @Override
        public void run() {
          if (type == 0){
            resultStr = "无";
          }else {
            resultStr = data;
          }
          if (_eventSink != null) {
            System.out.println(resultStr);
            _eventSink.success(resultStr);
          }
        }
      });
    }
  };

  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    System.out.println("onAttachedToEngine");

    methodChannel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "scan");
    methodChannel.setMethodCallHandler(new MethodChannel.MethodCallHandler() {
      @Override
      public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
        if (call.method.equals("getResult")) {
          System.out.println("AppTest");
          AppTest appTest = new AppTest();
          result.success(appTest.getResult());
          
        }
      }
    });

    eventChannel = new EventChannel(flutterPluginBinding.getBinaryMessenger(), "com.example.scan/event_channel_event");
    eventChannel.setStreamHandler(new EventChannel.StreamHandler() {
      @Override
      public void onListen(Object o, EventChannel.EventSink eventSink) {

        System.out.println("eventSink");
        _eventSink = eventSink;
        _eventSink.success("eventSink");
      }
      @Override
      public void onCancel(Object o) {
        _eventSink = null;
      }
    });
  }

//  @Override
//  protected void onCreate(Bundle savedInstanceState) {
//    super.onCreate(savedInstanceState);
//    //初始化接口对象
//    miScanInterface = new iScanInterface(this);
//    miScanInterface.registerScan(scanResltListener);
//  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    methodChannel.setMethodCallHandler(null);
  }

  public void onAttachedToActivity(@NonNull ActivityPluginBinding binding){
    System.out.println("----------------------onAttachedToActivity----------------------");
    Activity activity = binding.getActivity();
    //初始化接口对象
    miScanInterface = new iScanInterface(activity);
    miScanInterface.registerScan(scanResltListener);
  }

  @Override
  public void onDetachedFromActivityForConfigChanges(){

  }

  @Override
  public void onReattachedToActivityForConfigChanges(@NonNull ActivityPluginBinding binding){

  }


  @Override
  public void onDetachedFromActivity(){

  }


}
